@@ -51,23 +51,30 @@ class Rediz(RedizConventions):
     def get_donation_password(self):
         return muid.shash(self._obscurity)
 
-    def donate(self,write_key, password, verbose=True):
+    def donate(self,write_key, password, donor=None, verbose=True):
         official_password = self.get_donation_password()
+        donor = donor or 'anonymous'
         if password==official_password:
             len = muid.difficulty(write_key)
-            if len>=12:
-                self.client.lpush(self.donation_name(len=len),write_key=write_key)
+            if len>=self.MIN_LEN:
+                if self.client.sadd(self.donation_name(len=len),write_key):
+                    importance = 16**(len-self.MIN_LEN)
+                    self.client.hincrby(name=self.donors_name(),key=donor.lower(),amount=importance)
                 return {"operation":"donation","success":True,"message":"Thanks, you can view it at","url":self.base_url+"/donations/"+str(len)} if verbose else 1
             else:
                 return {"operation":"donation","success":False,"message":"Invalid write key or not long enough"} if verbose else 0
         else:
             return {"operation":"donation","success":False,"message":"Invalid password","hint":"Ends with "+str(official_password[-4:])} if verbose else 0
 
+    def get_donors(self):
+        donors = self.client.hgetall(self.donors_name())
+        return dict( sorted(donors.items(), key = lambda e:int(e[1]),reverse=True ) )
+
     def get_donations(self, len=None):
         if len is None:
             return [ muid.animal(write_key)  for difficulty in range(17,11,-1)  for write_key in self.get_donations(len=difficulty) ]
         else:
-            return self.client.lrange(self.donation_name(len=len),start=0,end=-1)
+            return self.client.smembers(self.donation_name(len=len))
 
     def get(self, name, as_json=False, **kwargs ):
         """ Unified getter expecting prefixed name - used by web application """
