@@ -90,6 +90,7 @@ class RedizConventions(MicroConventions):
         self._PROMISED = "promised" + self.SEP  # Prefixes temporary values referenced by the promise queue
         self._DONATIONS = "donations" + self.SEP  # Write key donations
         self._DONATION_PASSWORD = muid.shash(self._obscurity)  # Write key donation password
+        self._DONORS = "donors"
 
         # Other implementation config
         self._DELAY_GRACE = int(delay_grace or 5)  # Seconds beyond the schedule time when promise data expires
@@ -174,6 +175,9 @@ class RedizConventions(MicroConventions):
     def donation_name(self,len):
         return self._DONATIONS + str(len)
 
+    def donors_name(self):
+        return self._DONORS
+
     def identity(self, name):
         return name
 
